'''
all alerters should derive from this
'''
from threading import Thread
import Queue
import time
import atexit
import syslog

import log

class Alerter(Thread):
    
    def __init__(self, verifiedcache):
        self.vcache = verifiedcache
        self.pool = Queue.Queue()
        self._running = False
        Thread.__init__(self)
        atexit.register(self.stop)

    def stop(self):
        self._running = False

    def run(self):
        self._running = True
        while self._running:
            try:
                alert = self.pool.get_nowait()
            except Queue.Empty:
                time.sleep(1)
            else:
                try:
                    self.send_alert(alert)
                except Exception:
                    log.tb()

    def send_alert(self, alert):
        level, recset, message = alert
        print "[%s] %s %s: %s" % (level,recset.name, recset.type, message)
        return

    def error(self, recset, message):
        self.pool.put(('ERROR', recset, message))
        return

    def warning(self, recset, message):
        self.pool.put(('WARNING',recset,message))
        return

class SyslogAlerter(Alerter):

    def send_alert(self, alert):
        level, recset, message = alert
        message = "[%s] %s (%s %s): %s" % (level,recset.server, recset.name, recset.type, message)
        if level == 'ERROR':
            priority=syslog.LOG_ERR
        else:
            priority = syslog.LOG_INFO
        syslog.openlog('CacheAudit', syslog.LOG_PID|syslog.LOG_CONS,
                       syslog.LOG_LOCAL5)
        syslog.syslog(priority, message)
        syslog.closelog()
