'''
This file will hold different parsing engines
'''
import storage

def parse_msdns(lines):
    cachestore = storage.CacheStorage()
    for line in lines.split('\n'):
        line=line.rstrip()
        if not line:
            continue
        elif line.startswith(';'):
            # This is a comment
            continue
        elif line.startswith('\t\t'):
            # New entry
            line = line.lstrip()
            hdata,value = line.split('\t',1)
            ttl,type = hdata.split()
        elif line.startswith('\t'):
            # This is a continuation
            continue
        else:
            line = line.lstrip()
            hdata,value = line.split('\t',1)
            host,ttl,type = hdata.split()
        if host == '@':
            host = '.'
        if ttl != '0':
            cachestore.add_record(host.lower(), type, value, ttl)
    return cachestore

def parse_bind(lines):
    cachestore = storage.CacheStorage()
    inparens = False
    for line in lines.split('\n'):
        line=line.rstrip()
        if not line:
            continue
        elif line.startswith(';'):
            continue
        elif line.startswith('$'):
            continue
        if inparens:
            value += ' '+' '.join(line.split())
            if value.endswith(')'):
                inparens = False
                cachestore.add_record(host, type, value, ttl)
            continue
        if line.startswith('\t'):
            hdata = line.split()
            ttl = hdata[0]
            type = hdata[1]
            value = ' '.join(hdata[2:])
            if value.endswith('('):
                inparens = True
        else:
            hdata = line.split()
            host = hdata[0]
            ttl = hdata[1]
            type = hdata[2]
            value = ' '.join(hdata[3:])
            if value.endswith('('):
                inparens = True
        if not type.startswith("\\"):
            cachestore.add_record(host.lower(), type, value, ttl)
    return cachestore

def parse_pdns(lines):
    cachestore = storage.CacheStorage()
    for line in lines.split('\n'):
        line=line.rstrip()
        if not line:
            continue
        host,ttl,cls,type,value = line.split(' ', 4)
        try:
            ttl = int(ttl)
        except ValueError:
            continue
        if ttl <= 0:
            continue
        cachestore.add_record(host.lower(), type, value, ttl)
    return cachestore
